luma/definition
Main definitions used throughout the programm
Types
a single Instruction on how to change the state or to render text
pub type Instruction {
Text(String)
Push(StateObject)
Pop(mode.Type)
}
Constructors
-
Text(String) -
Push(StateObject) -
Pop(mode.Type)pop ignores the number
The main state of the parser with a list of each primitives and there state lists
pub type State {
State(
hirachystate: List(Int),
truthstate: List(Int),
markingstate: List(Int),
quotestate: List(Int),
)
}
Constructors
-
State( hirachystate: List(Int), truthstate: List(Int), markingstate: List(Int), quotestate: List(Int), )
A single primitive and its modifier
pub type StateObject {
Hirachy(Int)
Truth(Int)
Marking(Int)
Quote(Int)
}
Constructors
-
Hirachy(Int) -
Truth(Int) -
Marking(Int) -
Quote(Int)
A list of single instructions
pub type TextInstructions {
TextInstructions(List(Instruction))
}
Constructors
-
TextInstructions(List(Instruction))
Values
pub fn inline_to_json(inline: Instruction) -> json.Json